from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PconfigurationCls:
	"""Pconfiguration commands group definition. 25 total commands, 6 Subgroups, 15 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pconfiguration", core, parent)

	@property
	def bdaLap(self):
		"""bdaLap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdaLap'):
			from .BdaLap import BdaLapCls
			self._bdaLap = BdaLapCls(self._core, self._cmd_group)
		return self._bdaLap

	@property
	def bdaNap(self):
		"""bdaNap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdaNap'):
			from .BdaNap import BdaNapCls
			self._bdaNap = BdaNapCls(self._core, self._cmd_group)
		return self._bdaNap

	@property
	def bdaUap(self):
		"""bdaUap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdaUap'):
			from .BdaUap import BdaUapCls
			self._bdaUap = BdaUapCls(self._core, self._cmd_group)
		return self._bdaUap

	@property
	def coDevice(self):
		"""coDevice commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coDevice'):
			from .CoDevice import CoDeviceCls
			self._coDevice = CoDeviceCls(self._core, self._cmd_group)
		return self._coDevice

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def lfsWord(self):
		"""lfsWord commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lfsWord'):
			from .LfsWord import LfsWordCls
			self._lfsWord = LfsWordCls(self._core, self._cmd_group)
		return self._lfsWord

	# noinspection PyTypeChecker
	def get_acknowledgement(self) -> enums.BtoAckNldgmt:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:ACKNowledgement \n
		Snippet: value: enums.BtoAckNldgmt = driver.source.bb.btooth.pconfiguration.get_acknowledgement() \n
		Sets the ARQN bit of the packet header.. \n
			:return: acknowledgement: NAK| ACK NAK Request to retransmit the previous payload. ACK Previous payload has been received successfully.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:ACKNowledgement?')
		return Conversions.str_to_scalar_enum(response, enums.BtoAckNldgmt)

	def set_acknowledgement(self, acknowledgement: enums.BtoAckNldgmt) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:ACKNowledgement \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_acknowledgement(acknowledgement = enums.BtoAckNldgmt.ACK) \n
		Sets the ARQN bit of the packet header.. \n
			:param acknowledgement: NAK| ACK NAK Request to retransmit the previous payload. ACK Previous payload has been received successfully.
		"""
		param = Conversions.enum_scalar_to_str(acknowledgement, enums.BtoAckNldgmt)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:ACKNowledgement {param}')

	def get_byte_interleaving(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:BYTEInterleaving \n
		Snippet: value: bool = driver.source.bb.btooth.pconfiguration.get_byte_interleaving() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:BYTEInterleaving?')
		return Conversions.str_to_bool(response)

	def set_byte_interleaving(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:BYTEInterleaving \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_byte_interleaving(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:BYTEInterleaving {param}')

	def get_dlength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DLENgth \n
		Snippet: value: int = driver.source.bb.btooth.pconfiguration.get_dlength() \n
		Sets the payload data length in bytes. \n
			:return: dlength: integer Range: 0 to depends on packet type
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DLENgth?')
		return Conversions.str_to_int(response)

	def set_dlength(self, dlength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DLENgth \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_dlength(dlength = 1) \n
		Sets the payload data length in bytes. \n
			:param dlength: integer Range: 0 to depends on packet type
		"""
		param = Conversions.decimal_value_to_str(dlength)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DLENgth {param}')

	# noinspection PyTypeChecker
	def get_dsf_packet(self) -> enums.BtoDataSourForPck:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DSFPacket \n
		Snippet: value: enums.BtoDataSourForPck = driver.source.bb.btooth.pconfiguration.get_dsf_packet() \n
		Selects the data source for the selected packet type. \n
			:return: dsf_packet: PEDit| ADATa PED Enables the 'Packet Editor'. All packet fields can be configured individually. ADAT Fills the generated packets with the selected data source. Useful if predefined data contents are loaded with a data list file or the data contents of the packet are not of interest.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DSFPacket?')
		return Conversions.str_to_scalar_enum(response, enums.BtoDataSourForPck)

	def set_dsf_packet(self, dsf_packet: enums.BtoDataSourForPck) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DSFPacket \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_dsf_packet(dsf_packet = enums.BtoDataSourForPck.ADATa) \n
		Selects the data source for the selected packet type. \n
			:param dsf_packet: PEDit| ADATa PED Enables the 'Packet Editor'. All packet fields can be configured individually. ADAT Fills the generated packets with the selected data source. Useful if predefined data contents are loaded with a data list file or the data contents of the packet are not of interest.
		"""
		param = Conversions.enum_scalar_to_str(dsf_packet, enums.BtoDataSourForPck)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DSFPacket {param}')

	def get_dwhitening(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DWHitening \n
		Snippet: value: bool = driver.source.bb.btooth.pconfiguration.get_dwhitening() \n
		Activates the 'Data Whitening'. \n
			:return: dwhitening: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DWHitening?')
		return Conversions.str_to_bool(response)

	def set_dwhitening(self, dwhitening: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DWHitening \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_dwhitening(dwhitening = False) \n
		Activates the 'Data Whitening'. \n
			:param dwhitening: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(dwhitening)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DWHitening {param}')

	# noinspection PyTypeChecker
	def get_eir_packet_follows(self) -> enums.YesNoStatus:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:EIRPacketfollows \n
		Snippet: value: enums.YesNoStatus = driver.source.bb.btooth.pconfiguration.get_eir_packet_follows() \n
		Indicates that an extended inquiry response packet can follow. \n
			:return: eir_packet_follow: YES| NO YES Indicates that EIR packet follows. NO Indicates that EIR packet does not follow.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:EIRPacketfollows?')
		return Conversions.str_to_scalar_enum(response, enums.YesNoStatus)

	def set_eir_packet_follows(self, eir_packet_follow: enums.YesNoStatus) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:EIRPacketfollows \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_eir_packet_follows(eir_packet_follow = enums.YesNoStatus.NO) \n
		Indicates that an extended inquiry response packet can follow. \n
			:param eir_packet_follow: YES| NO YES Indicates that EIR packet follows. NO Indicates that EIR packet does not follow.
		"""
		param = Conversions.enum_scalar_to_str(eir_packet_follow, enums.YesNoStatus)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:EIRPacketfollows {param}')

	# noinspection PyTypeChecker
	def get_hf_control(self) -> enums.BtoFlowCtrl:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:HFControl \n
		Snippet: value: enums.BtoFlowCtrl = driver.source.bb.btooth.pconfiguration.get_hf_control() \n
		The command sets the FLOW bit in the header. This bit indicates start or stop of transmission of packets over the ACL
		logical transport. \n
			:return: hf_control: GO| STOP GO Allows the other devices to transmit new data. STOP Stops the other devices from transmitting data temporarily.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:HFControl?')
		return Conversions.str_to_scalar_enum(response, enums.BtoFlowCtrl)

	def set_hf_control(self, hf_control: enums.BtoFlowCtrl) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:HFControl \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_hf_control(hf_control = enums.BtoFlowCtrl.GO) \n
		The command sets the FLOW bit in the header. This bit indicates start or stop of transmission of packets over the ACL
		logical transport. \n
			:param hf_control: GO| STOP GO Allows the other devices to transmit new data. STOP Stops the other devices from transmitting data temporarily.
		"""
		param = Conversions.enum_scalar_to_str(hf_control, enums.BtoFlowCtrl)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:HFControl {param}')

	def get_hr_interleav(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:HRINterleav \n
		Snippet: value: int = driver.source.bb.btooth.pconfiguration.get_hr_interleav() \n
		No command help available \n
			:return: hr_interleaving: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:HRINterleav?')
		return Conversions.str_to_int(response)

	def set_hr_interleav(self, hr_interleaving: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:HRINterleav \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_hr_interleav(hr_interleaving = 1) \n
		No command help available \n
			:param hr_interleaving: No help available
		"""
		param = Conversions.decimal_value_to_str(hr_interleaving)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:HRINterleav {param}')

	def get_lt_address(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:LTADdress \n
		Snippet: value: int = driver.source.bb.btooth.pconfiguration.get_lt_address() \n
		The command enters the logical transport address for the header. Each Peripheral active in a piconet is assigned a
		primary logical transport address (LT_ADDR) . The all-zero LT_ADDR is reserved for broadcast messages. \n
			:return: lt_address: integer Range: 0 to 7
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:LTADdress?')
		return Conversions.str_to_int(response)

	def set_lt_address(self, lt_address: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:LTADdress \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_lt_address(lt_address = 1) \n
		The command enters the logical transport address for the header. Each Peripheral active in a piconet is assigned a
		primary logical transport address (LT_ADDR) . The all-zero LT_ADDR is reserved for broadcast messages. \n
			:param lt_address: integer Range: 0 to 7
		"""
		param = Conversions.decimal_value_to_str(lt_address)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:LTADdress {param}')

	# noinspection PyTypeChecker
	def get_pf_control(self) -> enums.BtoFlowCtrl:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:PFControl \n
		Snippet: value: enums.BtoFlowCtrl = driver.source.bb.btooth.pconfiguration.get_pf_control() \n
		The command sets the FLOW bit in the payload (flow control per logical link) . \n
			:return: pf_control: GO| STOP GO Indicates the start of transmission of ACL packets after a new connection has been established. STOP Indicates the stop of transmission of ACL packets before an additional amount of payload data is sent.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:PFControl?')
		return Conversions.str_to_scalar_enum(response, enums.BtoFlowCtrl)

	def set_pf_control(self, pf_control: enums.BtoFlowCtrl) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:PFControl \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_pf_control(pf_control = enums.BtoFlowCtrl.GO) \n
		The command sets the FLOW bit in the payload (flow control per logical link) . \n
			:param pf_control: GO| STOP GO Indicates the start of transmission of ACL packets after a new connection has been established. STOP Indicates the stop of transmission of ACL packets before an additional amount of payload data is sent.
		"""
		param = Conversions.enum_scalar_to_str(pf_control, enums.BtoFlowCtrl)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:PFControl {param}')

	def get_plength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:PLENgth \n
		Snippet: value: int = driver.source.bb.btooth.pconfiguration.get_plength() \n
		Sets the packet length in symbols. \n
			:return: plength: integer Range: 1 to depends on packet type
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:PLENgth?')
		return Conversions.str_to_int(response)

	def set_plength(self, plength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:PLENgth \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_plength(plength = 1) \n
		Sets the packet length in symbols. \n
			:param plength: integer Range: 1 to depends on packet type
		"""
		param = Conversions.decimal_value_to_str(plength)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:PLENgth {param}')

	def get_slap(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SLAP \n
		Snippet: value: bool = driver.source.bb.btooth.pconfiguration.get_slap() \n
		Activates synchronization of the lower address part (LAP) of the sync word and Bluetooth device address. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SLAP?')
		return Conversions.str_to_bool(response)

	def set_slap(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SLAP \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_slap(state = False) \n
		Activates synchronization of the lower address part (LAP) of the sync word and Bluetooth device address. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SLAP {param}')

	def get_sns_value(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SNSValue \n
		Snippet: value: int = driver.source.bb.btooth.pconfiguration.get_sns_value() \n
		Sets the start value of the header SEQN bit. The SEQN bit is present in the header to filter out retransmissions in the
		destination. The signal generator is altering this bit automatically on consecutive frames, if a sequence length of at
		least 2 frames is set. \n
			:return: sns_value: integer Range: 0 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SNSValue?')
		return Conversions.str_to_int(response)

	def set_sns_value(self, sns_value: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SNSValue \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_sns_value(sns_value = 1) \n
		Sets the start value of the header SEQN bit. The SEQN bit is present in the header to filter out retransmissions in the
		destination. The signal generator is altering this bit automatically on consecutive frames, if a sequence length of at
		least 2 frames is set. \n
			:param sns_value: integer Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(sns_value)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SNSValue {param}')

	# noinspection PyTypeChecker
	def get_sr_mode(self) -> enums.BtoScanReMode:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SRMode \n
		Snippet: value: enums.BtoScanReMode = driver.source.bb.btooth.pconfiguration.get_sr_mode() \n
		The command indicates the interval between two consecutive page scan windows, determines the behavior of the paging
		device. \n
			:return: sr_mode: R0| R1| R2 R0 The scan interval is equal to the scan window T w page scan (continuous nscan) and maximal 1.28s. R1 The scan interval is maximal 1.28s. R2 The scan interval is maximal 2.56s.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SRMode?')
		return Conversions.str_to_scalar_enum(response, enums.BtoScanReMode)

	def set_sr_mode(self, sr_mode: enums.BtoScanReMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:SRMode \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_sr_mode(sr_mode = enums.BtoScanReMode.R0) \n
		The command indicates the interval between two consecutive page scan windows, determines the behavior of the paging
		device. \n
			:param sr_mode: R0| R1| R2 R0 The scan interval is equal to the scan window T w page scan (continuous nscan) and maximal 1.28s. R1 The scan interval is maximal 1.28s. R2 The scan interval is maximal 2.56s.
		"""
		param = Conversions.enum_scalar_to_str(sr_mode, enums.BtoScanReMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:SRMode {param}')

	# noinspection PyTypeChecker
	def get_vdata(self) -> enums.DataSourceB:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:VDATa \n
		Snippet: value: enums.DataSourceB = driver.source.bb.btooth.pconfiguration.get_vdata() \n
		Selects the data source for the voice field. \n
			:return: vdata: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:VDATa?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceB)

	def set_vdata(self, vdata: enums.DataSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:VDATa \n
		Snippet: driver.source.bb.btooth.pconfiguration.set_vdata(vdata = enums.DataSourceB.ALL0) \n
		Selects the data source for the voice field. \n
			:param vdata: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt
		"""
		param = Conversions.enum_scalar_to_str(vdata, enums.DataSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:VDATa {param}')

	def clone(self) -> 'PconfigurationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PconfigurationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImpairmentsCls:
	"""Impairments commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impairments", core, parent)

	def get_cc_error(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:CCERror \n
		Snippet: value: int = driver.source.bb.huwb.impairments.get_cc_error() \n
		Sets the chip clock error of the impairment symbols. \n
			:return: st_error: integer Range: -300 to 300
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:IMPairments:CCERror?')
		return Conversions.str_to_int(response)

	def set_cc_error(self, st_error: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:CCERror \n
		Snippet: driver.source.bb.huwb.impairments.set_cc_error(st_error = 1) \n
		Sets the chip clock error of the impairment symbols. \n
			:param st_error: integer Range: -300 to 300
		"""
		param = Conversions.decimal_value_to_str(st_error)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:IMPairments:CCERror {param}')

	def get_foffset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:FOFFset \n
		Snippet: value: int = driver.source.bb.huwb.impairments.get_foffset() \n
		Sets the chip clock error of the impairment symbols. \n
			:return: foffset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:IMPairments:FOFFset?')
		return Conversions.str_to_int(response)

	def set_foffset(self, foffset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:FOFFset \n
		Snippet: driver.source.bb.huwb.impairments.set_foffset(foffset = 1) \n
		Sets the chip clock error of the impairment symbols. \n
			:param foffset: integer Range: -300 to 300
		"""
		param = Conversions.decimal_value_to_str(foffset)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:IMPairments:FOFFset {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:STATe \n
		Snippet: value: bool = driver.source.bb.huwb.impairments.get_state() \n
		Sets the chip clock error of the impairment symbols. \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:HUWB:IMPairments:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:HUWB:IMPairments:STATe \n
		Snippet: driver.source.bb.huwb.impairments.set_state(state = False) \n
		Sets the chip clock error of the impairment symbols. \n
			:param state: integer Range: -300 to 300
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:HUWB:IMPairments:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def set(self, power: float, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:[HSUPa]:DPDCh:E:POWer \n
		Snippet: driver.source.bb.w3Gpp.mstation.hsupa.dpdch.e.power.set(power = 1.0, mobileStation = repcap.MobileStation.Default) \n
		No command help available \n
			:param power: No help available
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
		"""
		param = Conversions.decimal_value_to_str(power)
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:HSUPa:DPDCh:E:POWer {param}')

	def get(self, mobileStation=repcap.MobileStation.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:[HSUPa]:DPDCh:E:POWer \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.hsupa.dpdch.e.power.get(mobileStation = repcap.MobileStation.Default) \n
		No command help available \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: power: No help available"""
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:HSUPa:DPDCh:E:POWer?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, freq_corr_mag_stat: bool, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:USER:FLISt<CH>:MAGNitude:[STATe] \n
		Snippet: driver.source.correction.fresponse.iq.user.flist.magnitude.state.set(freq_corr_mag_stat = False, index = repcap.Index.Default) \n
		No command help available \n
			:param freq_corr_mag_stat: No help available
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		param = Conversions.bool_to_str(freq_corr_mag_stat)
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:IQ:USER:FLISt{index_cmd_val}:MAGNitude:STATe {param}')

	def get(self, index=repcap.Index.Default) -> bool:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:USER:FLISt<CH>:MAGNitude:[STATe] \n
		Snippet: value: bool = driver.source.correction.fresponse.iq.user.flist.magnitude.state.get(index = repcap.Index.Default) \n
		No command help available \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
			:return: freq_corr_mag_stat: No help available"""
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SOURce<HwInstance>:CORRection:FRESponse:IQ:USER:FLISt{index_cmd_val}:MAGNitude:STATe?')
		return Conversions.str_to_bool(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InfoCls:
	"""Info commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("info", core, parent)

	def get(self, index=repcap.Index.Default) -> List[str]:
		"""SCPI: SCONfiguration:EXTernal:DIGital<CH>:REMote:INFO \n
		Snippet: value: List[str] = driver.sconfiguration.external.digital.remote.info.get(index = repcap.Index.Default) \n
		Queries information on the external instrument. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Digital')
			:return: id_pi_db_ext_dev_rem_inst_info: string Returns information in one of the following formats: 'None' An external instrument is not assigned SymbolicName,RemoteChannel,RemoteAddress,RF Path An external instrument is assigned, but not connected SymbolicName,RemoteChannel,RemoteAddress,RF Path[,*IDN? String] An external instrument is assigned and connected"""
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SCONfiguration:EXTernal:DIGital{index_cmd_val}:REMote:INFO?')
		return Conversions.str_to_str_list(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConfigureCls:
	"""Configure commands group definition. 14 total commands, 5 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("configure", core, parent)

	@property
	def blank(self):
		"""blank commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_blank'):
			from .Blank import BlankCls
			self._blank = BlankCls(self._core, self._cmd_group)
		return self._blank

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def marker(self):
		"""marker commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def segment(self):
		"""segment commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_segment'):
			from .Segment import SegmentCls
			self._segment = SegmentCls(self._core, self._cmd_group)
		return self._segment

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:CATalog \n
		Snippet: value: List[str] = driver.source.bb.arbitrary.wsegment.configure.get_catalog() \n
		Queries the available configuration files in the default directory. See also 'File concept'. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_comment(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:COMMent \n
		Snippet: value: str = driver.source.bb.arbitrary.wsegment.configure.get_comment() \n
		Enters a comment for the selected configuration file. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:COMMent \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.set_comment(comment = 'abc') \n
		Enters a comment for the selected configuration file. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:COMMent {param}')

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:DELete \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.delete(filename = 'abc') \n
		Deletes the selected configuration file. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:DELete {param}')

	def get_ofile(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:OFILe \n
		Snippet: value: str = driver.source.bb.arbitrary.wsegment.configure.get_ofile() \n
		Defines the file name of the output multi-segment waveform. \n
			:return: ofile: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:OFILe?')
		return trim_str_response(response)

	def set_ofile(self, ofile: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:OFILe \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.set_ofile(ofile = 'abc') \n
		Defines the file name of the output multi-segment waveform. \n
			:param ofile: string
		"""
		param = Conversions.value_to_quoted_str(ofile)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:OFILe {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:SELect \n
		Snippet: value: str = driver.source.bb.arbitrary.wsegment.configure.get_select() \n
		Selects a configuration file from the default directory. If a configuration file with the specified name does not yet
		exist, it is created. The file extension *.inf_mswv may be omitted. \n
			:return: filename: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:SELect \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.set_select(filename = 'abc') \n
		Selects a configuration file from the default directory. If a configuration file with the specified name does not yet
		exist, it is created. The file extension *.inf_mswv may be omitted. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:SELect {param}')

	def clone(self) -> 'ConfigureCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ConfigureCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 5 total commands, 2 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dpattern(self):
		"""dpattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpattern'):
			from .Dpattern import DpatternCls
			self._dpattern = DpatternCls(self._core, self._cmd_group)
		return self._dpattern

	@property
	def vdPattern(self):
		"""vdPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vdPattern'):
			from .VdPattern import VdPatternCls
			self._vdPattern = VdPatternCls(self._core, self._cmd_group)
		return self._vdPattern

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.btooth.pconfiguration.data.get_dselection() \n
		The command selects data list file. \n
			:return: dselection: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, dselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA:DSELection \n
		Snippet: driver.source.bb.btooth.pconfiguration.data.set_dselection(dselection = 'abc') \n
		The command selects data list file. \n
			:param dselection: string
		"""
		param = Conversions.value_to_quoted_str(dselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA:DSELection {param}')

	def get_vd_selection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA:VDSElection \n
		Snippet: value: str = driver.source.bb.btooth.pconfiguration.data.get_vd_selection() \n
		Selects the data list for voice data. \n
			:return: vd_selection: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA:VDSElection?')
		return trim_str_response(response)

	def set_vd_selection(self, vd_selection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA:VDSElection \n
		Snippet: driver.source.bb.btooth.pconfiguration.data.set_vd_selection(vd_selection = 'abc') \n
		Selects the data list for voice data. \n
			:param vd_selection: string
		"""
		param = Conversions.value_to_quoted_str(vd_selection)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA:VDSElection {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.DataSourceB:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA \n
		Snippet: value: enums.DataSourceB = driver.source.bb.btooth.pconfiguration.data.get_value() \n
		Selects the data source used for the payload. \n
			:return: data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceB)

	def set_value(self, data: enums.DataSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PCONfiguration:DATA \n
		Snippet: driver.source.bb.btooth.pconfiguration.data.set_value(data = enums.DataSourceB.ALL0) \n
		Selects the data source used for the payload. \n
			:param data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PCONfiguration:DATA {param}')

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RepmpdcchCls:
	"""Repmpdcch commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("repmpdcch", core, parent)

	def set(self, max_rep_mpdcch: enums.EutraEmtcMpdcchNumRepetitions, userIx=repcap.UserIx.Default, cellNull=repcap.CellNull.Default, setItem=repcap.SetItem.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:EPDCch:CELL<ST0>:SET<DIR>:REPMpdcch \n
		Snippet: driver.source.bb.eutra.downlink.user.epdcch.cell.set.repmpdcch.set(max_rep_mpdcch = enums.EutraEmtcMpdcchNumRepetitions._1, userIx = repcap.UserIx.Default, cellNull = repcap.CellNull.Default, setItem = repcap.SetItem.Default) \n
		Sets the maximum number the MPDCCH is repeated. \n
			:param max_rep_mpdcch: 1| 2| 4| 8| 16| 32| 64| 128| 256
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param setItem: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')
		"""
		param = Conversions.enum_scalar_to_str(max_rep_mpdcch, enums.EutraEmtcMpdcchNumRepetitions)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		setItem_cmd_val = self._cmd_group.get_repcap_cmd_value(setItem, repcap.SetItem)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:EPDCch:CELL{cellNull_cmd_val}:SET{setItem_cmd_val}:REPMpdcch {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default, cellNull=repcap.CellNull.Default, setItem=repcap.SetItem.Default) -> enums.EutraEmtcMpdcchNumRepetitions:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:EPDCch:CELL<ST0>:SET<DIR>:REPMpdcch \n
		Snippet: value: enums.EutraEmtcMpdcchNumRepetitions = driver.source.bb.eutra.downlink.user.epdcch.cell.set.repmpdcch.get(userIx = repcap.UserIx.Default, cellNull = repcap.CellNull.Default, setItem = repcap.SetItem.Default) \n
		Sets the maximum number the MPDCCH is repeated. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param setItem: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')
			:return: max_rep_mpdcch: 1| 2| 4| 8| 16| 32| 64| 128| 256"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		setItem_cmd_val = self._cmd_group.get_repcap_cmd_value(setItem, repcap.SetItem)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:EPDCch:CELL{cellNull_cmd_val}:SET{setItem_cmd_val}:REPMpdcch?')
		return Conversions.str_to_scalar_enum(response, enums.EutraEmtcMpdcchNumRepetitions)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CarrierCls:
	"""Carrier commands group definition. 10 total commands, 7 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("carrier", core, parent)

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import ConflictCls
			self._conflict = ConflictCls(self._core, self._cmd_group)
		return self._conflict

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import DelayCls
			self._delay = DelayCls(self._core, self._cmd_group)
		return self._delay

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import PhaseCls
			self._phase = PhaseCls(self._core, self._cmd_group)
		return self._phase

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def get_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:COUNt \n
		Snippet: value: int = driver.source.bb.arbitrary.mcarrier.carrier.get_count() \n
		Sets the number of carriers in the ARB multi-carrier waveform. \n
			:return: count: integer Range: 1 to 512
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:COUNt?')
		return Conversions.str_to_int(response)

	def set_count(self, count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:COUNt \n
		Snippet: driver.source.bb.arbitrary.mcarrier.carrier.set_count(count = 1) \n
		Sets the number of carriers in the ARB multi-carrier waveform. \n
			:param count: integer Range: 1 to 512
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:COUNt {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbMultCarrSpacMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:MODE \n
		Snippet: value: enums.ArbMultCarrSpacMode = driver.source.bb.arbitrary.mcarrier.carrier.get_mode() \n
		The command sets the carrier frequency mode. \n
			:return: mode: EQUidistant| ARBitrary
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbMultCarrSpacMode)

	def set_mode(self, mode: enums.ArbMultCarrSpacMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:MODE \n
		Snippet: driver.source.bb.arbitrary.mcarrier.carrier.set_mode(mode = enums.ArbMultCarrSpacMode.ARBitrary) \n
		The command sets the carrier frequency mode. \n
			:param mode: EQUidistant| ARBitrary
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbMultCarrSpacMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:MODE {param}')

	def get_spacing(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:SPACing \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.carrier.get_spacing() \n
		Sets the frequency spacing between adjacent carriers of the multi-carrier waveform (see 'Defining the carrier frequency')
		. \n
			:return: spacing: float Range: 0.0 to depends on the installed options, e.g. 120E6, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:SPACing?')
		return Conversions.str_to_float(response)

	def set_spacing(self, spacing: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:CARRier:SPACing \n
		Snippet: driver.source.bb.arbitrary.mcarrier.carrier.set_spacing(spacing = 1.0) \n
		Sets the frequency spacing between adjacent carriers of the multi-carrier waveform (see 'Defining the carrier frequency')
		. \n
			:param spacing: float Range: 0.0 to depends on the installed options, e.g. 120E6, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(spacing)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:CARRier:SPACing {param}')

	def clone(self) -> 'CarrierCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CarrierCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DurationCls:
	"""Duration commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("duration", core, parent)

	def set(self, drs_duration: enums.EutraDrsDuration, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH0>:DURation \n
		Snippet: driver.source.bb.eutra.downlink.drs.cell.duration.set(drs_duration = enums.EutraDrsDuration.DUR1, cellNull = repcap.CellNull.Default) \n
		Sets the DRS duration. \n
			:param drs_duration: DUR1| DUR2| DUR3| DUR4| DUR5 DUR1 For LAA SCells, the DRS is always 1 ms long DUR2|DUR3|DUR4|DUR5 In FDD mode, sets duration of 2 ms to 5 ms
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.enum_scalar_to_str(drs_duration, enums.EutraDrsDuration)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{cellNull_cmd_val}:DURation {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default) -> enums.EutraDrsDuration:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH0>:DURation \n
		Snippet: value: enums.EutraDrsDuration = driver.source.bb.eutra.downlink.drs.cell.duration.get(cellNull = repcap.CellNull.Default) \n
		Sets the DRS duration. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: drs_duration: DUR1| DUR2| DUR3| DUR4| DUR5 DUR1 For LAA SCells, the DRS is always 1 ms long DUR2|DUR3|DUR4|DUR5 In FDD mode, sets duration of 2 ms to 5 ms"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{cellNull_cmd_val}:DURation?')
		return Conversions.str_to_scalar_enum(response, enums.EutraDrsDuration)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BtoothCls:
	"""Btooth commands group definition. 380 total commands, 21 Subgroups, 18 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("btooth", core, parent)

	@property
	def ccrc(self):
		"""ccrc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccrc'):
			from .Ccrc import CcrcCls
			self._ccrc = CcrcCls(self._core, self._cmd_group)
		return self._ccrc

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import ClippingCls
			self._clipping = ClippingCls(self._core, self._cmd_group)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def cs(self):
		"""cs commands group. 9 Sub-classes, 13 commands."""
		if not hasattr(self, '_cs'):
			from .Cs import CsCls
			self._cs = CsCls(self._core, self._cmd_group)
		return self._cs

	@property
	def dtTest(self):
		"""dtTest commands group. 3 Sub-classes, 7 commands."""
		if not hasattr(self, '_dtTest'):
			from .DtTest import DtTestCls
			self._dtTest = DtTestCls(self._core, self._cmd_group)
		return self._dtTest

	@property
	def econfig(self):
		"""econfig commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_econfig'):
			from .Econfig import EconfigCls
			self._econfig = EconfigCls(self._core, self._cmd_group)
		return self._econfig

	@property
	def econfiguration(self):
		"""econfiguration commands group. 4 Sub-classes, 11 commands."""
		if not hasattr(self, '_econfiguration'):
			from .Econfiguration import EconfigurationCls
			self._econfiguration = EconfigurationCls(self._core, self._cmd_group)
		return self._econfiguration

	@property
	def filterPy(self):
		"""filterPy commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def hdr(self):
		"""hdr commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_hdr'):
			from .Hdr import HdrCls
			self._hdr = HdrCls(self._core, self._cmd_group)
		return self._hdr

	@property
	def hr(self):
		"""hr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hr'):
			from .Hr import HrCls
			self._hr = HrCls(self._core, self._cmd_group)
		return self._hr

	@property
	def mhdt(self):
		"""mhdt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mhdt'):
			from .Mhdt import MhdtCls
			self._mhdt = MhdtCls(self._core, self._cmd_group)
		return self._mhdt

	@property
	def msettings(self):
		"""msettings commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_msettings'):
			from .Msettings import MsettingsCls
			self._msettings = MsettingsCls(self._core, self._cmd_group)
		return self._msettings

	@property
	def pconfiguration(self):
		"""pconfiguration commands group. 6 Sub-classes, 15 commands."""
		if not hasattr(self, '_pconfiguration'):
			from .Pconfiguration import PconfigurationCls
			self._pconfiguration = PconfigurationCls(self._core, self._cmd_group)
		return self._pconfiguration

	@property
	def phymacCfg(self):
		"""phymacCfg commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_phymacCfg'):
			from .PhymacCfg import PhymacCfgCls
			self._phymacCfg = PhymacCfgCls(self._core, self._cmd_group)
		return self._phymacCfg

	@property
	def pramping(self):
		"""pramping commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_pramping'):
			from .Pramping import PrampingCls
			self._pramping = PrampingCls(self._core, self._cmd_group)
		return self._pramping

	@property
	def qhs(self):
		"""qhs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_qhs'):
			from .Qhs import QhsCls
			self._qhs = QhsCls(self._core, self._cmd_group)
		return self._qhs

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def symbolRate(self):
		"""symbolRate commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def trigger(self):
		"""trigger commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def unit(self):
		"""unit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	# noinspection PyTypeChecker
	def get_bc_role(self) -> enums.BtoCtrlRol:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:BCRole \n
		Snippet: value: enums.BtoCtrlRol = driver.source.bb.btooth.get_bc_role() \n
		Determines the controller role. Depending on the selected channel type different roles are assigned to the controller.
		For channel type 'Data', Central or Peripheral can be assigned. If channel type 'Advertising' is selected, the parameter
		is read only and displayed directly above the graph. \n
			:return: bc_role: CENTral| PERipheral| ADVertiser| SCANner| INITiator CENTral Selects Central as controller role. PERipheral Selects Peripheral as controller role. ADVertiser|SCANner|INITiator Assigned roles depending on the selected packet type of the respective channel type.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:BCRole?')
		return Conversions.str_to_scalar_enum(response, enums.BtoCtrlRol)

	def set_bc_role(self, bc_role: enums.BtoCtrlRol) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:BCRole \n
		Snippet: driver.source.bb.btooth.set_bc_role(bc_role = enums.BtoCtrlRol.ADVertiser) \n
		Determines the controller role. Depending on the selected channel type different roles are assigned to the controller.
		For channel type 'Data', Central or Peripheral can be assigned. If channel type 'Advertising' is selected, the parameter
		is read only and displayed directly above the graph. \n
			:param bc_role: CENTral| PERipheral| ADVertiser| SCANner| INITiator CENTral Selects Central as controller role. PERipheral Selects Peripheral as controller role. ADVertiser|SCANner|INITiator Assigned roles depending on the selected packet type of the respective channel type.
		"""
		param = Conversions.enum_scalar_to_str(bc_role, enums.BtoCtrlRol)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:BCRole {param}')

	def get_bc_text(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:BCText \n
		Snippet: value: str = driver.source.bb.btooth.get_bc_text() \n
		Queries the state and controller role. \n
			:return: bc_text: string Connected (only data channel type) Advertiser (only advertising channel type) ADV_IND, ADV_DIRECT_IND, ADV_NONCONN_IND, ADV_SCAN_IND Within R&S SMBVB-K117 also ADV_EXT_IND, AUX_ADV_IND, AUX_SYNC_IND, AUX_CHAIN_IND Scanner (only advertising channel type) SCAN_REQ, SCAN_RSP Within R&S SMBVB-K117 also AUX_SCAN_REQ, AUX_SCAN_RSP Initiator (only advertising channel type) CONNECT_IND Within R&S SMBVB-K117 also AUX_CONNECT_REQ, AUX_CONNECT_RSP
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:BCText?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_bmode(self) -> enums.BtoMode:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:BMODe \n
		Snippet: value: enums.BtoMode = driver.source.bb.btooth.get_bmode() \n
		Determines the Bluetooth mode. \n
			:return: bmode: BASic| BLENergy BASic Selects Bluetooth mode BR + EDR. BLENergy Selects Bluetooth LE.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:BMODe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoMode)

	def set_bmode(self, bmode: enums.BtoMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:BMODe \n
		Snippet: driver.source.bb.btooth.set_bmode(bmode = enums.BtoMode.BASic) \n
		Determines the Bluetooth mode. \n
			:param bmode: BASic| BLENergy BASic Selects Bluetooth mode BR + EDR. BLENergy Selects Bluetooth LE.
		"""
		param = Conversions.enum_scalar_to_str(bmode, enums.BtoMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:BMODe {param}')

	# noinspection PyTypeChecker
	def get_ctype(self) -> enums.BtoChnnelType:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CTYPe \n
		Snippet: value: enums.BtoChnnelType = driver.source.bb.btooth.get_ctype() \n
		Determines the channel type. Advertising and data are available. \n
			:return: ctype: ADVertising| DATA ADVertising Selects channel type advertising. DATA Selects channel type data. Devices in a connected state transmit data channel packets in connection events with a start point and an interval.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:CTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoChnnelType)

	def set_ctype(self, ctype: enums.BtoChnnelType) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CTYPe \n
		Snippet: driver.source.bb.btooth.set_ctype(ctype = enums.BtoChnnelType.ADVertising) \n
		Determines the channel type. Advertising and data are available. \n
			:param ctype: ADVertising| DATA ADVertising Selects channel type advertising. DATA Selects channel type data. Devices in a connected state transmit data channel packets in connection events with a start point and an interval.
		"""
		param = Conversions.enum_scalar_to_str(ctype, enums.BtoChnnelType)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CTYPe {param}')

	# noinspection PyTypeChecker
	def get_dcycle(self) -> enums.LowHigh:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DCYCle \n
		Snippet: value: enums.LowHigh = driver.source.bb.btooth.get_dcycle() \n
		Specifies duty cycle for directed advertising (packet type ADV_DIRECT_IND) . \n
			:return: dcycle: LOW| HIGH
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DCYCle?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)

	def set_dcycle(self, dcycle: enums.LowHigh) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DCYCle \n
		Snippet: driver.source.bb.btooth.set_dcycle(dcycle = enums.LowHigh.HIGH) \n
		Specifies duty cycle for directed advertising (packet type ADV_DIRECT_IND) . \n
			:param dcycle: LOW| HIGH
		"""
		param = Conversions.enum_scalar_to_str(dcycle, enums.LowHigh)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DCYCle {param}')

	def get_duration(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DURation \n
		Snippet: value: float = driver.source.bb.btooth.get_duration() \n
		Specifies the transmission duration of CONTINUOUS payload transmission. Command sets the values in ms. Query returns
		values in s. \n
			:return: duration: float Range: depending on modulation format, symbols per a bit and payload type , Unit: ms
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DURation \n
		Snippet: driver.source.bb.btooth.set_duration(duration = 1.0) \n
		Specifies the transmission duration of CONTINUOUS payload transmission. Command sets the values in ms. Query returns
		values in s. \n
			:param duration: float Range: depending on modulation format, symbols per a bit and payload type , Unit: ms
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DURation {param}')

	# noinspection PyTypeChecker
	def get_hdrp_phy(self) -> enums.BtoHdrpPhy:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:HDRPphy \n
		Snippet: value: enums.BtoHdrpPhy = driver.source.bb.btooth.get_hdrp_phy() \n
		No command help available \n
			:return: hdrp_phy: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:HDRPphy?')
		return Conversions.str_to_scalar_enum(response, enums.BtoHdrpPhy)

	def set_hdrp_phy(self, hdrp_phy: enums.BtoHdrpPhy) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:HDRPphy \n
		Snippet: driver.source.bb.btooth.set_hdrp_phy(hdrp_phy = enums.BtoHdrpPhy.HDRP4) \n
		No command help available \n
			:param hdrp_phy: No help available
		"""
		param = Conversions.enum_scalar_to_str(hdrp_phy, enums.BtoHdrpPhy)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:HDRPphy {param}')

	# noinspection PyTypeChecker
	def get_mformat(self) -> enums.PackFormat:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:MFORmat \n
		Snippet: value: enums.PackFormat = driver.source.bb.btooth.get_mformat() \n
		Specifies the physical layer used for CONTINUOUS payload transmission. \n
			:return: mod_fmt: L1M| L2M| LCOD L1M: LE 1M L2M: LE 2M LCOD: LE coded
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:MFORmat?')
		return Conversions.str_to_scalar_enum(response, enums.PackFormat)

	def set_mformat(self, mod_fmt: enums.PackFormat) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:MFORmat \n
		Snippet: driver.source.bb.btooth.set_mformat(mod_fmt = enums.PackFormat.L1M) \n
		Specifies the physical layer used for CONTINUOUS payload transmission. \n
			:param mod_fmt: L1M| L2M| LCOD L1M: LE 1M L2M: LE 2M LCOD: LE coded
		"""
		param = Conversions.enum_scalar_to_str(mod_fmt, enums.PackFormat)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:MFORmat {param}')

	# noinspection PyTypeChecker
	def get_pformat(self) -> enums.BtoPackFormat:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PFORmat \n
		Snippet: value: enums.BtoPackFormat = driver.source.bb.btooth.get_pformat() \n
		Specifies the physical layer of LE signal. \n
			:return: pformat: L1M| L2M| LCOD L1M LE 1M L2M LE 2M LCOD LE coded
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PFORmat?')
		return Conversions.str_to_scalar_enum(response, enums.BtoPackFormat)

	def set_pformat(self, pformat: enums.BtoPackFormat) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PFORmat \n
		Snippet: driver.source.bb.btooth.set_pformat(pformat = enums.BtoPackFormat.BLE4M) \n
		Specifies the physical layer of LE signal. \n
			:param pformat: L1M| L2M| LCOD L1M LE 1M L2M LE 2M LCOD LE coded
		"""
		param = Conversions.enum_scalar_to_str(pformat, enums.BtoPackFormat)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PFORmat {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PRESet \n
		Snippet: driver.source.bb.btooth.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:BTOoth:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PRESet \n
		Snippet: driver.source.bb.btooth.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:BTOoth:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:BTOoth:PRESet', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_ptype(self) -> enums.BtoPckType:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PTYPe \n
		Snippet: value: enums.BtoPckType = driver.source.bb.btooth.get_ptype() \n
		The available packets depend on the selected transport mode. All packet types as defined in the Bluetooth specifications
		are supported. \n
			:return: ptype: ID| NULL| POLL| FHS| DM1| DH1| DM3| DH3| DM5| DH5| AUX1| ADH1| ADH3| ADH5| AEDH1| AEDH3| AEDH5| HV1| HV2| HV3| DV| EV3| EV4| EV5| EEV3| EEV5| EEEV3| EEEV5
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoPckType)

	def set_ptype(self, ptype: enums.BtoPckType) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PTYPe \n
		Snippet: driver.source.bb.btooth.set_ptype(ptype = enums.BtoPckType.ADH1) \n
		The available packets depend on the selected transport mode. All packet types as defined in the Bluetooth specifications
		are supported. \n
			:param ptype: ID| NULL| POLL| FHS| DM1| DH1| DM3| DH3| DM5| DH5| AUX1| ADH1| ADH3| ADH5| AEDH1| AEDH3| AEDH5| HV1| HV2| HV3| DV| EV3| EV4| EV5| EEV3| EEV5| EEEV3| EEEV5
		"""
		param = Conversions.enum_scalar_to_str(ptype, enums.BtoPckType)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PTYPe {param}')

	def get_slength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:SLENgth \n
		Snippet: value: int = driver.source.bb.btooth.get_slength() \n
		Sets the sequence length of the Bluetooth signal in number of frames. This signal is calculated in advance and output in
		the arbitrary waveform generator. \n
			:return: slength: integer Range: depends on the number of states in dirty transmitter test to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:SLENgth \n
		Snippet: driver.source.bb.btooth.set_slength(slength = 1) \n
		Sets the sequence length of the Bluetooth signal in number of frames. This signal is calculated in advance and output in
		the arbitrary waveform generator. \n
			:param slength: integer Range: depends on the number of states in dirty transmitter test to dynamic
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:SLENgth {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:STATe \n
		Snippet: value: bool = driver.source.bb.btooth.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:STATe \n
		Snippet: driver.source.bb.btooth.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:STATe {param}')

	# noinspection PyTypeChecker
	def get_stiming(self) -> enums.BtoSlotTiming:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:STIMing \n
		Snippet: value: enums.BtoSlotTiming = driver.source.bb.btooth.get_stiming() \n
		Selects the Rx slot timing mode. \n
			:return: slot_timing: TX| LOOPback
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:STIMing?')
		return Conversions.str_to_scalar_enum(response, enums.BtoSlotTiming)

	def set_stiming(self, slot_timing: enums.BtoSlotTiming) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:STIMing \n
		Snippet: driver.source.bb.btooth.set_stiming(slot_timing = enums.BtoSlotTiming.LOOPback) \n
		Selects the Rx slot timing mode. \n
			:param slot_timing: TX| LOOPback
		"""
		param = Conversions.enum_scalar_to_str(slot_timing, enums.BtoSlotTiming)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:STIMing {param}')

	# noinspection PyTypeChecker
	def get_tmode(self) -> enums.BtoTranMode:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:TMODe \n
		Snippet: value: enums.BtoTranMode = driver.source.bb.btooth.get_tmode() \n
		Selects the transport mode. \n
			:return: tmode: ACL| SCO| ESCO ACL Asynchronous connection-less mode used for a point-to-point multipoint link between a Central and all Peripherals. SCO Synchronous connection-oriented mode used for a point-to-point link between a Central and a specific Peripheral. ESCO Enhanced synchronous connection-oriented mode used for a symmetric or asymmetric point-to point link between a Central and a specific Peripheral.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:TMODe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoTranMode)

	def set_tmode(self, tmode: enums.BtoTranMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:TMODe \n
		Snippet: driver.source.bb.btooth.set_tmode(tmode = enums.BtoTranMode.ACL) \n
		Selects the transport mode. \n
			:param tmode: ACL| SCO| ESCO ACL Asynchronous connection-less mode used for a point-to-point multipoint link between a Central and all Peripherals. SCO Synchronous connection-oriented mode used for a point-to-point link between a Central and a specific Peripheral. ESCO Enhanced synchronous connection-oriented mode used for a symmetric or asymmetric point-to point link between a Central and a specific Peripheral.
		"""
		param = Conversions.enum_scalar_to_str(tmode, enums.BtoTranMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:TMODe {param}')

	# noinspection PyTypeChecker
	def get_up_type(self) -> enums.BtoUlpPckType:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:UPTYpe \n
		Snippet: value: enums.BtoUlpPckType = driver.source.bb.btooth.get_up_type() \n
		Selects the packet type. The available packets depend on the selected channel type and installed options. The tables
		below provide an overview. For more information, see data sheet. R&S SMBVB-K60 packet/PDU types
			Table Header: <UpType> / Packet/PDU type \n
			- AIND ADINd ANINd SREQ SRSP CREQ ADCind DATA CUReq CMReq TIND EREQ / ADV_IND ADV_DIRECT_IND ADV_NONCONN_IND SCAN_REQ SCAN_RSP CONNECT_IND ADV_SCAN_IND DATA LL_CONNECTION_UPDATE_IND LL_CHANNEL_MAP_IND LL_TERMINATE_IND LL_ENC_REQ
			- ERSP SEReq SERSp URSP FREQ FRSP TPACket PEReq PERSp VIND RIND / LL_ENC_RSP LL_START_ENC_REQ LL_START_ENC_RSP LL_UNKNONW_RSP LL_FEATURE_REQ LL_FEATURE_RSP TEST PACKET LL_PAUSE_ENC_REQ LL_PAUSE_ENC_RSP LL_VERSION_IND LL_REJECT_IND
		R&S SMBVB-K117 packet/PDU types
			Table Header: <UpType> / Packet/PDU type \n
			- PREQ PRSP PUIN LRSP SFR CPR CPRS REIN PIR PIRS AEINd AAINd ACINd / LL_PHY_REQ LL_PHY_RSP LL_PHY_UPDATE_IND LL_LENGTH_RSP LL_PERIPHERAL_FEATURE_REQ LL_CONNECTION_PARAM_REQ LL_CONNECTION_PARAM_RSP LL_REJECT_EXT_IND LL_PING_REQ LL_PING_RSP ADV_EXT_IND AUX_ADV_IND AUX_CHAIN_IND
			- ASINd ASReq ASPSp ACRSp ACReq MUCH CONT CTEQ CTEP PSIND CAReq CARSp / AUX_SYNC_IND AUX_SCAN_REQ AUX_SCAN_RSP AUX_CONNECT_RSP AUX_CONNECT_REQ LL_MIN_USED_CHANNELS_IND CONTINUOUS LL_CTE_REQ LL_CTE_RSP LL_PERIODIC_SYNC LL_CLOCK_ACCURACY_REQ LL_CLOCK_ACCURACY_RSP \n
			:return: up_type: AIND| ADINd| ANINd| SREQ| SRSP| CREQ| ADCind| DATA| CUReq| CMReq| TIND| EREQ| ERSP| SEReq| SERSp| URSP| FREQ| FRSP| TPACket| PEReq| PERSp| VIND| RIND| PREQ| PRSP| PUIN| LREQ| LRSP| SFR| CPR| CPRS| REIN| PIR| PIRS| AEINd| AAINd| ACINd| ASINd| ASReq| ASPSp| ACRSp| ACReq| MUCH| CONT| CTEQ| CTEP| PSINd| CAReq| CARSp
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:UPTYpe?')
		return Conversions.str_to_scalar_enum(response, enums.BtoUlpPckType)

	def set_up_type(self, up_type: enums.BtoUlpPckType) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:UPTYpe \n
		Snippet: driver.source.bb.btooth.set_up_type(up_type = enums.BtoUlpPckType.AAINd) \n
		Selects the packet type. The available packets depend on the selected channel type and installed options. The tables
		below provide an overview. For more information, see data sheet. R&S SMBVB-K60 packet/PDU types
			Table Header: <UpType> / Packet/PDU type \n
			- AIND ADINd ANINd SREQ SRSP CREQ ADCind DATA CUReq CMReq TIND EREQ / ADV_IND ADV_DIRECT_IND ADV_NONCONN_IND SCAN_REQ SCAN_RSP CONNECT_IND ADV_SCAN_IND DATA LL_CONNECTION_UPDATE_IND LL_CHANNEL_MAP_IND LL_TERMINATE_IND LL_ENC_REQ
			- ERSP SEReq SERSp URSP FREQ FRSP TPACket PEReq PERSp VIND RIND / LL_ENC_RSP LL_START_ENC_REQ LL_START_ENC_RSP LL_UNKNONW_RSP LL_FEATURE_REQ LL_FEATURE_RSP TEST PACKET LL_PAUSE_ENC_REQ LL_PAUSE_ENC_RSP LL_VERSION_IND LL_REJECT_IND
		R&S SMBVB-K117 packet/PDU types
			Table Header: <UpType> / Packet/PDU type \n
			- PREQ PRSP PUIN LRSP SFR CPR CPRS REIN PIR PIRS AEINd AAINd ACINd / LL_PHY_REQ LL_PHY_RSP LL_PHY_UPDATE_IND LL_LENGTH_RSP LL_PERIPHERAL_FEATURE_REQ LL_CONNECTION_PARAM_REQ LL_CONNECTION_PARAM_RSP LL_REJECT_EXT_IND LL_PING_REQ LL_PING_RSP ADV_EXT_IND AUX_ADV_IND AUX_CHAIN_IND
			- ASINd ASReq ASPSp ACRSp ACReq MUCH CONT CTEQ CTEP PSIND CAReq CARSp / AUX_SYNC_IND AUX_SCAN_REQ AUX_SCAN_RSP AUX_CONNECT_RSP AUX_CONNECT_REQ LL_MIN_USED_CHANNELS_IND CONTINUOUS LL_CTE_REQ LL_CTE_RSP LL_PERIODIC_SYNC LL_CLOCK_ACCURACY_REQ LL_CLOCK_ACCURACY_RSP \n
			:param up_type: AIND| ADINd| ANINd| SREQ| SRSP| CREQ| ADCind| DATA| CUReq| CMReq| TIND| EREQ| ERSP| SEReq| SERSp| URSP| FREQ| FRSP| TPACket| PEReq| PERSp| VIND| RIND| PREQ| PRSP| PUIN| LREQ| LRSP| SFR| CPR| CPRS| REIN| PIR| PIRS| AEINd| AAINd| ACINd| ASINd| ASReq| ASPSp| ACRSp| ACReq| MUCH| CONT| CTEQ| CTEP| PSINd| CAReq| CARSp
		"""
		param = Conversions.enum_scalar_to_str(up_type, enums.BtoUlpPckType)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:UPTYpe {param}')

	def get_us_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:USLength \n
		Snippet: value: int = driver.source.bb.btooth.get_us_length() \n
		Selects the number of frames or events depending on the packet type. The signal repeats after the specified number of
		frames/events. For SCAN_REQ and CONNECT_IND packet, the sequence length is expressed in 'Frames'. For AUX_SCAN_REQ and
		AUX_CONNECT_REQ packet, the sequence length is expressed in 'Frames'. For LL_TERMINATE_IND packets, a default value
		according to the specification is given: Central: PeripheralLatency + 6 Peripheral: 6 For all other packet types the
		sequence length is expressed in 'Events'. \n
			:return: us_length: integer Range: depends on the number of states in dirty transmitter test to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:USLength?')
		return Conversions.str_to_int(response)

	def set_us_length(self, us_length: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:USLength \n
		Snippet: driver.source.bb.btooth.set_us_length(us_length = 1) \n
		Selects the number of frames or events depending on the packet type. The signal repeats after the specified number of
		frames/events. For SCAN_REQ and CONNECT_IND packet, the sequence length is expressed in 'Frames'. For AUX_SCAN_REQ and
		AUX_CONNECT_REQ packet, the sequence length is expressed in 'Frames'. For LL_TERMINATE_IND packets, a default value
		according to the specification is given: Central: PeripheralLatency + 6 Peripheral: 6 For all other packet types the
		sequence length is expressed in 'Events'. \n
			:param us_length: integer Range: depends on the number of states in dirty transmitter test to dynamic
		"""
		param = Conversions.decimal_value_to_str(us_length)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:USLength {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:VERSion \n
		Snippet: value: str = driver.source.bb.btooth.get_version() \n
		Queries the version of the specification for Bluetooth wireless technology underlying the definitions. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'BtoothCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BtoothCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NeededCls:
	"""Needed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("needed", core, parent)

	def get_state(self) -> bool:
		"""SCPI: SYSTem:PCIFpga:UPDate:NEEDed:[STATe] \n
		Snippet: value: bool = driver.system.pciFpga.update.needed.get_state() \n
		No command help available \n
			:return: update_needed: No help available
		"""
		response = self._core.io.query_str('SYSTem:PCIFpga:UPDate:NEEDed:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExecuteCls:
	"""Execute commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("execute", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:GPS:EXECute \n
		Snippet: driver.source.bb.gnss.sv.importPy.gps.execute.set() \n
		Triggers the import of constellation and navigation data from the selected files. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:GPS:EXECute')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:GPS:EXECute \n
		Snippet: driver.source.bb.gnss.sv.importPy.gps.execute.set_with_opc() \n
		Triggers the import of constellation and navigation data from the selected files. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:GPS:EXECute', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResolveCls:
	"""Resolve commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("resolve", core, parent)

	def set(self, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:TXBW:RESolve \n
		Snippet: driver.source.bb.nr5G.node.cell.txbw.resolve.set(cellNull = repcap.CellNull.Default) \n
		Recalculates the frequency-dependent settings and thus redefines the frequency position of the TxBW. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:TXBW:RESolve')

	def set_with_opc(self, cellNull=repcap.CellNull.Default, opc_timeout_ms: int = -1) -> None:
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:TXBW:RESolve \n
		Snippet: driver.source.bb.nr5G.node.cell.txbw.resolve.set_with_opc(cellNull = repcap.CellNull.Default) \n
		Recalculates the frequency-dependent settings and thus redefines the frequency position of the TxBW. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:TXBW:RESolve', opc_timeout_ms)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PerdCls:
	"""Perd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("perd", core, parent)

	def set(self, periodicity: enums.EutraPracNbiotPeriodicity, configurationNull=repcap.ConfigurationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:CFG<CH0>:PERD \n
		Snippet: driver.source.bb.eutra.uplink.prach.niot.cfg.perd.set(periodicity = enums.EutraPracNbiotPeriodicity._10240, configurationNull = repcap.ConfigurationNull.Default) \n
		Sets NPRACH periodicity. \n
			:param periodicity: 40| 80| 160| 240| 320| 640| 1280| 2560 | 5120| 10240
			:param configurationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cfg')
		"""
		param = Conversions.enum_scalar_to_str(periodicity, enums.EutraPracNbiotPeriodicity)
		configurationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(configurationNull, repcap.ConfigurationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:CFG{configurationNull_cmd_val}:PERD {param}')

	# noinspection PyTypeChecker
	def get(self, configurationNull=repcap.ConfigurationNull.Default) -> enums.EutraPracNbiotPeriodicity:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:CFG<CH0>:PERD \n
		Snippet: value: enums.EutraPracNbiotPeriodicity = driver.source.bb.eutra.uplink.prach.niot.cfg.perd.get(configurationNull = repcap.ConfigurationNull.Default) \n
		Sets NPRACH periodicity. \n
			:param configurationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cfg')
			:return: periodicity: 40| 80| 160| 240| 320| 640| 1280| 2560 | 5120| 10240"""
		configurationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(configurationNull, repcap.ConfigurationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:CFG{configurationNull_cmd_val}:PERD?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPracNbiotPeriodicity)
